@@ -1,5 +1,5 @@
 package Perl::MinimumVersion;
-$Perl::MinimumVersion::VERSION = '1.36';
+$Perl::MinimumVersion::VERSION = '1.38';
 =pod
 
 =head1 NAME
@@ -30,6 +30,13 @@ Future plans are to also add support for tracing module dependencies.
 Using C<Perl::MinimumVersion> is dead simple, the synopsis pretty much
 covers it.
 
+The distribution comes with a script called L<perlver>,
+which is the easiest way to run C<Perl::MinimumVersion> on your code:
+
+ % perlver lib/Foo/Bar.pm
+
+See the L<documentation for perlver|perlver> for more details.
+
 =head1 METHODS
 
 =cut
@@ -59,7 +66,7 @@ BEGIN {
 
 	# The primary list of version checks
 	%CHECKS = (
-        _stacked_labels         => version->new('5.014'),
+        # _stacked_labels         => version->new('5.014'),
 
 		_yada_yada_yada         => version->new('5.012'),
 		_pkg_name_version       => version->new('5.012'),
@@ -1424,6 +1431,12 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
+L<perlver> - the command-line script for running C<Perl::MinimumVersion>
+on your code.
+
+L<Perl::MinimumVersion::Fast> - another module which does the same thing.
+It's a lot faster, but only supports Perl 5.8.1+.
+
 L<http://ali.as/>, L<PPI>, L<version>
 
 =head1 REPOSITORY
